var moment = require("moment");
var fs = require("fs");
var proc = require("child_process");
var path = require('path')
var os = require('os');

var mongoCommand = "mongodump.exe";

//Get all variables from process
var dbBaseDir=process.argv[2];

//Get all mongo DB connection parameters.
var mongoInstallDir = process.env.MONGO_INSTALL_DIR;
var mongoPort = process.env.MONGO_PORT;
var mongoUser = process.env.MONGO_USERNAME;
var mongoPassword = process.env.MONGO_PASSWORD;
var mongoDBName = process.argv[3];

var currDateTime = moment().format('YYYYMMDD-HHmmss');

function createDir(dirName) {
  if(isDirExists(dirName)){
    console.info("Directory already exists-"+dirName);
    return;
  }
  fs.mkdirSync(dirName);
}

function isDirExists(dirName) {
  return fs.existsSync(dirName);
}
function usage() {
  console.info(os.EOL + "Usage-" + os.EOL + "node " + path.basename(__filename) + " d:\\backup ivm" + os.EOL + "node " + 
      path.basename(__filename) + " /opt/backup eai");
  process.exit(-1);
}

function validateField(isValid, errorMessage) {
  if(!isValid) {
    console.error(errorMessage);
    usage();
  }
}
function validateInput() {
  validateField(dbBaseDir&&isDirExists(dbBaseDir), "Please provide valid backup directory.") ;
  validateField(mongoDBName, "Please provide database name.") ;
  validateField(mongoInstallDir, "Environment variable MONGO_INSTALL_DIR is not set.");
  validateField(mongoPort, "Environment variable MONGO_PORT is not set.");
  validateField(mongoUser, "Environment variable MONGO_USERNAME is not set.");
  validateField(mongoPassword, "Environment variable MONGO_PASSWORD is not set.");
}

console.info("Database backup directory name-"+dbBaseDir);
console.info("Mongo install location-"+mongoInstallDir);

validateInput();

//Create DB backup directory.
dbBaseDir = path.resolve(dbBaseDir);
var dbFinalDir = dbBaseDir + path.sep + currDateTime;
createDir(dbFinalDir);

console.info("Now backing up database-" + mongoDBName);
process.chdir(mongoInstallDir);

var cmd = mongoCommand + " -u " + mongoUser + " -p " + mongoPassword + " --authenticationDatabase " + 
mongoDBName + " -d " + mongoDBName + " -o " + dbFinalDir;
console.info("Command directory-" + dbBaseDir);
console.info("Command to execute-" + cmd);

var result = proc.exec(cmd, function(error, stdout, stderr) {
  if (error) {
    console.error("Failed to execute command-"+error);
  }
  console.info("Stdout from command-"+stdout);
  console.info("Stderr from command-"+stderr);
});

console.info("Backup attempted for database-" + mongoDBName);



