'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _messages = require('../messages');

var _validator = require('validator');

var _validator2 = _interopRequireDefault(_validator);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Field = function (_React$Component) {
  _inherits(Field, _React$Component);

  function Field() {
    _classCallCheck(this, Field);

    return _possibleConstructorReturn(this, (Field.__proto__ || Object.getPrototypeOf(Field)).apply(this, arguments));
  }

  _createClass(Field, [{
    key: 'checkBlank',
    value: function checkBlank(text) {
      var trimmedText = text || text === 0 ? (0, _lodash.trim)(text) : undefined;
      return !(text || text === 0) || trimmedText.length === 0;
    }
  }, {
    key: 'fieldIsInvalid',
    value: function fieldIsInvalid() {
      var _props = this.props,
          onInvalid = _props.onInvalid,
          displayName = _props.displayName,
          docField = _props.docField;

      if (onInvalid) {
        onInvalid(true, displayName, docField);
      }
    }
  }, {
    key: 'fieldIsValid',
    value: function fieldIsValid() {
      var _props2 = this.props,
          onInvalid = _props2.onInvalid,
          displayName = _props2.displayName,
          docField = _props2.docField;

      if (onInvalid) {
        onInvalid(false, displayName, docField);
      }
    }
  }, {
    key: 'checkMandatory',
    value: function checkMandatory(text, newProps) {
      var props = newProps || this.props;
      var isRequired = props.isRequired;

      var isTextBlank = this.checkBlank(text);
      if (isRequired && isTextBlank) {
        throw new Error(_messages.DisplayMessages.requiredText);
      }
      return;
    }
  }, {
    key: 'checkValidation',
    value: function checkValidation(text, validatorTypeIn) {
      var validatorType = this.props.validatorType;

      var validatorToUse = validatorType || validatorTypeIn;
      if (!validatorToUse) {
        return;
      }

      if (!this.checkBlank(text) && !_validator2.default[validatorToUse]('' + text)) {
        throw new Error(_messages.DisplayMessages.invalidText);
      }
    }
  }, {
    key: 'checkRegex',
    value: function checkRegex(text) {
      var validationRegex = this.props.validationRegex;

      if (this.checkBlank(text) || !validationRegex) {
        return;
      }
      var pattern = new RegExp(validationRegex);
      var response = text.match(pattern);
      if (!response) {
        throw new Error(_messages.DisplayMessages.regexFail + '  ' + validationRegex);
      }
    }
  }, {
    key: 'checkRange',
    value: function checkRange(number) {
      var _props3 = this.props,
          minValue = _props3.minValue,
          maxValue = _props3.maxValue;

      if (!this.checkBlank(minValue) && !isNaN(minValue)) {
        if ((0, _lodash.toNumber)(number) < (0, _lodash.toNumber)(minValue)) {
          throw new Error(_messages.DisplayMessages.lowerRangeFail + (0, _lodash.toNumber)(minValue));
        }
      }
      if (!this.checkBlank(maxValue) && !isNaN(maxValue)) {
        if ((0, _lodash.toNumber)(number) > (0, _lodash.toNumber)(maxValue)) {
          throw new Error(_messages.DisplayMessages.upperRangeFail + (0, _lodash.toNumber)(maxValue));
        }
      }
    }
  }, {
    key: 'render',
    value: function render() {
      return;
    }
  }]);

  return Field;
}(_react2.default.Component);

exports.default = Field;


Field.propTypes = {
  displayName: _react2.default.PropTypes.string,
  value: _react2.default.PropTypes.any,
  docField: _react2.default.PropTypes.string,
  onChange: _react2.default.PropTypes.func.isRequired,
  isRequired: _react2.default.PropTypes.bool,
  minValue: _react2.default.PropTypes.number,
  maxValue: _react2.default.PropTypes.number,
  decimalPlaces: _react2.default.PropTypes.number,
  validatorType: _react2.default.PropTypes.string,
  onInvalid: _react2.default.PropTypes.func,
  validationRegex: _react2.default.PropTypes.string
};